@@ -141,6 +141,11 @@ class AWebspaceSettings(BaseSetting, ClusterableModel):
         default='',
         help_text="Text qui apparait en haut des articles en lien"
     )
+    related_portfolios_text = RichTextField(
+        blank=True,
+        default='',
+        help_text="Text qui apparait en haut des portfolios en lien"
+    )
 
     multi_header = models.BooleanField(
         default=True,
